#!/bin/bash
#$ -cwd

CHR=$1
CHUNK_START=`printf "%.0f" $2`
CHUNK_END=`printf "%.0f" $3`

# directories
ROOT_DIR=./
DATA_DIR=${ROOT_DIR}data_files/
RESULTS_DIR=${ROOT_DIR}results/
HAP_SAMP_DIR=${ROOT_DIR}sampled_haps/

# executable
IMPUTE2_EXEC=${ROOT_DIR}impute2

# parameters
NE=11500

# reference data files
GENMAP_FILE=${DATA_DIR}genetic_map_chr${CHR}_combined_b36.txt
HAPS_FILE=${DATA_DIR}pilot1.jun2010.b36.CEU.chr${CHR}.snpfilt.haps
LEGEND_FILE=${DATA_DIR}pilot1.jun2010.b36.CEU.chr${CHR}.snpfilt.legend

# best-guess haplotypes from phasing run
GWAS_BG_HAPS_FILE=${RESULTS_DIR}gwas_data_chr${CHR}.pos${CHUNK_START}-${CHUNK_END}.phasing.impute2_haps

# main output file
OUTPUT_FILE=${RESULTS_DIR}gwas_data_chr${CHR}.pos${CHUNK_START}-${CHUNK_END}.best_guess_haps_imputation.impute2

## impute genotypes from best-guess GWAS haplotypes
$IMPUTE2_EXEC \
    -m $GENMAP_FILE \
    -known_haps_g $GWAS_BG_HAPS_FILE \
    -h $HAPS_FILE \
    -l $LEGEND_FILE \
    -Ne $NE \
    -int $CHUNK_START $CHUNK_END \
    -o $OUTPUT_FILE 

